==> cpsi-react-web-component-app-0.4.0.tgz: package/src/components/ComingSoonAndPastCardComponent.jsx <==
import { Card, CardActionArea, CardContent, Typography } from '@material-ui/core';
import React, { useState, useEffect } from 'react';
import '../App.css';
import greenLogo from './Green-Icon.png';
import orangeLogo from './Orange-Icon.png';

type Props = {
    header: string,
    datetype: string,
    date: string,
    color: string,
    description: string,
    headingLogo: string
};
export default function CardComponent({ header, datetype, date, color, description, headingLogo }: Props) {
    debugger;
    return (
        <Card>
            <CardActionArea>
                <CardContent>
                    <div className={`period-card ${color == 'green' ? 'green-card' : 'orange-card'}`}>
                        <div class="grid-frame">
                            <div class="period-card-title">
                                <div class="period-icon">
                                    <img src={color == 'green' ? greenLogo : orangeLogo} alt='headingLogo' class="heading-logo" />
                                </div>
                                <div class="period-card-title-text">
                                    <div class="period-page-title">
                                        <div class="period-reporting-period-text">
                                            {header}
                                        </div>
                                    </div>
                                </div>
                                <div class="period-card-menu">
                                    <div class="three-dots-icon">
                                        <div class="three-dots">
                                            <div class="three-dots-rectangle"></div>
                                            <div class="three-dots-rectangle"></div>
                                            <div class="three-dots-rectangle"></div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div class="period-dates">
                                <p class="period-open-date">
                                    <b>{datetype}:</b> {date}
                                </p>
                            </div>
                            <div class="period-description">
                                <p class="period-description-text">
                                    {description}
                                </p>
                            </div>
                        </div>
                    </div>
                </CardContent>
            </CardActionArea >
        </Card >
    );
};

==> cpsi-react-web-component-app-0.5.0.tgz: package/src/components/ComingSoonAndPastCardComponent.jsx <==
import { Card, CardActionArea, CardContent, Typography } from '@material-ui/core';
import React, { useState, useEffect } from 'react';
import '../App.css';
import greenLogo from './Green-Icon.png';
import orangeLogo from './Orange-Icon.png';

type Props = {
    header: string,
    datetype: string,
    date: string,
    color: string,
    description: string
};
export default function ComingSoonAndPastCardComponent({ header, datetype, date, color, description }: Props) {
    debugger;
    return (
        <Card>
            <CardActionArea>
                <CardContent>
                    <div className={`period-card ${color == 'green' ? 'green-card' : 'orange-card'}`}>
                        <div class="grid-frame">
                            <div class="period-card-title">
                                <div class="period-icon">
                                    <img src={color == 'green' ? greenLogo : orangeLogo} alt='headingLogo' class="heading-logo" />
                                </div>
                                <div class="period-card-title-text">
                                    <div class="period-page-title">
                                        <div class="period-reporting-period-text">
                                            {header}
                                        </div>
                                    </div>
                                </div>
                                <div class="period-card-menu">
                                    <div class="three-dots-icon">
                                        <div class="three-dots">
                                            <div class="three-dots-rectangle"></div>
                                            <div class="three-dots-rectangle"></div>
                                            <div class="three-dots-rectangle"></div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div class="period-dates">
                                <p class="period-open-date">
                                    <b>{datetype}:</b> {date}
                                </p>
                            </div>
                            <div class="period-description">
                                <p class="period-description-text">
                                    {description}
                                </p>
                            </div>
                        </div>
                    </div>
                </CardContent>
            </CardActionArea >
        </Card >
    );
};
